@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use Carp;
 use vars qw($VERSION);
-$VERSION="0.02";
+$VERSION="0.05";
 
 use base qw( Tk::AppWindow::Ext::MDI );
 
@@ -112,6 +112,8 @@ sub new {
 	$self->cmdConfig(
 		doc_autoindent => ['docAutoIndent', $self],
 		doc_find => ['docPopFindReplace', $self, 1],
+		doc_get_sel => ['docGetSel', $self],
+		doc_get_text => ['docGetText', $self],
 		doc_replace => ['docPopFindReplace', $self, 0],
 		doc_wrap => ['docWrap', $self],
 		edit_delete => ['editDelete', $self],
@@ -152,6 +154,26 @@ sub contentModified {
 	return @_;
 }
 
+sub ContextMenu {
+	my $self = shift;
+	return $self->extGet('MenuBar')->menuContext($self->GetAppWindow,
+     [ 'menu_normal',    undef,  '~Copy',  '     <Control-c>',	 'edit-copy',       '*CTRL+C'], 
+     [ 'menu_normal',    undef,  'C~ut',        '<Control-x>',	 'edit-cut',        '*CTRL+X'], 
+     [ 'menu_normal',    undef,  '~Paste',      '<Control-v>',	 'edit-paste',      '*CTRL+V'], 
+     [ 'menu_separator', undef,  'c1'], 
+     [ 'menu_normal',    undef,  '~Select all', '<Control-a>',  'edit-select-all', '*CTRL+A'], 
+     [ 'menu_separator', undef,  'c2'], 
+     [ 'menu_normal',    undef,  'Co~mment',    '<Control-g>',   undef,            '*CTRL+G'], 
+     [ 'menu_normal',    undef,  '~Uncomment',  '<Control-G>',   undef,            '*CTRL+SHIFT+G'], 
+     [ 'menu_separator', undef,  'c3' ], 
+     [ 'menu_normal',    undef,  '~Indent',     '<Control-j>',   undef,            '*CTRL+J'], 
+     [ 'menu_normal',    undef,  'Unin~dent',   '<Control-J>',   undef,            '*CTRL+SHIFT+J'], 
+     [ 'menu_separator', undef,  'c4' ], 
+     [ 'menu_check',     undef,  'A~uto indent', undef, '-doc_autoindent', undef, 0, 1], 
+     [ 'menu_radio_s',   undef,  '~Wrap',  [qw/char word none/],  undef, '-doc_wrap'], 
+ 	)
+}
+
 sub CreateContentHandler {
 	my ($self, $name) = @_;
 	my $h = $self->SUPER::CreateContentHandler($name);
@@ -175,6 +197,20 @@ sub docAutoIndent {
 	return $self->docOption('-contentautoindent', @_);
 }
 
+sub docGetSel {
+	my $self = shift;
+	my $doc = $self->docSelected;
+	return unless defined $doc;
+	return $self->docGet($doc)->tagRanges('sel');
+}
+
+sub docGetText {
+	my $self = shift;
+	my $doc = $self->docSelected;
+	return unless defined $doc;
+	return $self->docGet($doc)->get(@_);
+}
+
 sub docOption {
 	my $self = shift;
 	my $item = shift;
@@ -237,7 +273,7 @@ sub editDelete {
 	my $self = shift;
 	my $doc = $self->docSelected;
 	return unless defined $doc;
-	$self->docGet($doc)->delete(@_) if defined $doc;
+	$self->docGet($doc)->delete(@_);
 }
 
 
@@ -251,38 +287,81 @@ sub editInsert {
 	my $self = shift;
 	my $doc = $self->docSelected;
 	return unless defined $doc;
-	$self->docGet($doc)->insert(@_) if defined $doc;
+	$self->docGet($doc)->insert(@_);
 }
 
+#sub HighlightConfigure {
+#	my $self = shift;
+#	my $dialog = $self->{DIALOG};
+#	unless (defined $dialog) {
+#		my ($first) = $self->docList;
+#		my $doc = $self->docGet($first);
+#		return () unless defined $doc;
+#		my $themefile = $doc->cget('-highlight_themefile');
+#		my $historyfile = $self->extGet('ConfigFolder')->ConfigFolder . '/color_history';
+#		my @opt = (
+#			-applycall => sub {
+#				my $themefile = shift;
+#				my @list = $self->docList;
+#				for (@list) {
+#					my $d = $self->docGet($_);
+#					$d->configure(-highlight_themefile => $themefile);
+#				}
+#			},
+#			-defaultbackground => $doc->cget('-contentbackground'),
+#			-defaultforeground => $doc->cget('-contentforeground'),
+#			-defaultfont => $doc->cget('-contentfont'),
+#			-historyfile => $historyfile,
+#			-themefile => $themefile,
+#			-height => 20,
+#			-width => 60,
+#		);
+#		$dialog = $self->YADialog(
+#			-title => 'Configure highlighting',
+#			-buttons => ['Close'],
+#		);
+#		$self->{DIALOG} = $dialog;
+#		my $editor = $dialog->CoditTagsEditor(@opt)->pack(-expand => 1, -fill => 'both');
+#		my $button = $dialog->Subwidget('buttonframe')->Button(
+#			-text => 'Apply',
+#			-command => ['Apply' => $editor],
+#		);
+#		$dialog->ButtonPack($button);
+#	}
+#
+#	$dialog->Show(-popover => $self->GetAppWindow);
+##	$dialog->destroy;
+#}
 
 sub MenuItems {
 	my $self = shift;
 	my @items = $self->SUPER::MenuItems;
 	return (@items,
+#      [	'menu_normal',		 'appname::h2',		    '~Highlighting',	     'highlighting',	         'configure',		    'SHIFT+F9',	], 
       [ 'menu',           undef,             '~Edit'], 
       [ 'menu_normal',    'Edit::',           '~Copy',             '<Control-c>',	      'edit-copy',      '*CTRL+C'], 
-      [ 'menu_normal',    'Edit::',          'C~ut',					'<Control-x>',			'edit-cut',	      '*CTRL+X'], 
-      [ 'menu_normal',    'Edit::',          '~Paste',            '<Control-v>',	      'edit-paste',     '*CTRL+V'], 
+      [ 'menu_normal',    'Edit::',          'C~ut',					          '<Control-x>',			    'edit-cut',	      '*CTRL+X'], 
+      [ 'menu_normal',    'Edit::',          '~Paste',             '<Control-v>',	      'edit-paste',     '*CTRL+V'], 
       [ 'menu_separator', 'Edit::',          'e1' ], 
-      [ 'menu_normal',    'Edit::',          'U~ndo',             '<Control-z>',       'edit-undo',      '*CTRL+Z'], 
-      [ 'menu_normal',    'Edit::',          '"~Redo',            '<Control-Z>',       'edit-redo',      '*CTRL+SHIFT+Z'], 
+      [ 'menu_normal',    'Edit::',          'U~ndo',              '<Control-z>',       'edit-undo',      '*CTRL+Z'], 
+      [ 'menu_normal',    'Edit::',          '"~Redo',             '<Control-Z>',       'edit-redo',      '*CTRL+SHIFT+Z'], 
       [ 'menu_separator', 'Edit::',          'e2'], 
-      [ 'menu_normal',    'Edit::',          'Co~mment',          '<Control-g>',       undef,            '*CTRL+G'], 
-      [ 'menu_normal',    'Edit::',          '~Uncomment',        '<Control-G>',       undef,            '*CTRL+SHIFT+G'], 
+      [ 'menu_normal',    'Edit::',          'Co~mment',           '<Control-g>',       undef,            '*CTRL+G'], 
+      [ 'menu_normal',    'Edit::',          '~Uncomment',         '<Control-G>',       undef,            '*CTRL+SHIFT+G'], 
       [ 'menu_separator', 'Edit::',          'e3' ], 
-      [ 'menu_normal',    'Edit::',          '~Indent',           '<Control-j>',       undef,            '*CTRL+J'], 
-      [ 'menu_normal',    'Edit::',          'Unin~dent',         '<Control-J>',       undef,            '*CTRL+SHIFT+J'], 
+      [ 'menu_normal',    'Edit::',          '~Indent',            '<Control-j>',       undef,            '*CTRL+J'], 
+      [ 'menu_normal',    'Edit::',          'Unin~dent',          '<Control-J>',       undef,            '*CTRL+SHIFT+J'], 
       [ 'menu_separator', 'Edit::',          'e4' ], 
-      [ 'menu_normal',    'Edit::',          '~Select all',       '<Control-a>',       'edit-select-all','*CTRL+A'], 
+      [ 'menu_normal',    'Edit::',          '~Select all',        '<Control-a>',       'edit-select-all','*CTRL+A'], 
       [ 'menu_separator', 'View::',          'v1' ],
       [ 'menu_check',     'View::',          'Show ~folds',          undef,   '-doc_view_folds', undef, 0, 1], 
       [ 'menu_check',     'View::',          'Show ~line numbers',   undef,   '-doc_view_numbers', undef, 0, 1], 
       [ 'menu_check',     'View::',          'Show ~document status',undef,   '-doc_view_status', undef, 0, 1], 
       [ 'menu',           undef,             '~Tools'],
-      [ 'menu_normal',    'Tools::',         '~Find',             'doc_find',          'edit-find',      'CTRL+F',],
-      [ 'menu_normal',    'Tools::',         '~Replace',	         'doc_replace',       'edit-find-replace','CTRL+R',],
+      [ 'menu_normal',    'Tools::',         '~Find',              'doc_find',          'edit-find',      'CTRL+F',],
+      [ 'menu_normal',    'Tools::',         '~Replace',	          'doc_replace',       'edit-find-replace','CTRL+R',],
       [ 'menu_separator', 'Tools::',          't1' ],
-      [ 'menu_check',     'Tools::',          'A~uto indent',     undef,   '-doc_autoindent', undef, 0, 1], 
+      [ 'menu_check',     'Tools::',          'A~uto indent',        undef,   '-doc_autoindent', undef, 0, 1], 
 #       [ 'menu',           'Tools::',          '~Wrap'],
       [ 'menu_radio_s',   'Tools::',          '~Wrap',  [qw/char word none/],  undef, '-doc_wrap'], 
 	);
